export class Main extends Indicator {

    constructor() {
        super();

        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            ExtMapBuffer1 : this.addBuffer(),
            ExtMapBuffer2 : this.addBuffer(),
        };
    }

    onInit() {
        this.buffers.ExtMapBuffer1
            .setShape(Shape.Arrow)
            .setAnchor(Anchor.Top)
            .setColor(Color.MediumSeaGreen)
            .setArrow(ArrowSymbols.ArrowDoubleUpWards)
            .setWidth(1);

        this.buffers.ExtMapBuffer2
            .setShape(Shape.Arrow)
            .setAnchor(Anchor.Bottom)
            .setColor(Color.Red)
            .setArrow(ArrowSymbols.ArrowDoubleDownWards)
            .setWidth(1);
    }

    async onUpdate() {
        const {PriceType} = this.getInputs(),
            {ExtMapBuffer1, ExtMapBuffer2} = this.buffers,
            {High, Low, Close} = await Bar.load([Bar.Mode.High, Bar.Mode.Low, Bar.Mode.Close], PriceType),
            barSize = High.length;

        let countedBars = Bar.counted();

        if (countedBars < 0) return;
        if (countedBars > 0) countedBars--;

        let pos = barSize - countedBars,
            rsiList = await Indicators.RSI(null, 0, 14, AppliedPrice.Close, PriceType),
            sarList = await Indicators.SAR(null, 0, 0.02, 0.2, PriceType);

        while (pos >= 0) {
            let rsi14 = rsiList[pos] || 0,
                rsi14_1 = rsiList[pos + 1] || 0,
                rsi14_2 = rsiList[pos + 2] || 0,
                sar = sarList[pos] || 0,
                low = Low[pos] || 0,
                high = High[pos] || 0;

            if ((rsi14 >= 30 && sar < low)
                && rsi14 > rsi14_1
                && rsi14 > rsi14_2) {
                ExtMapBuffer1.set(pos, (low - 5 * Current.Point));
            }
            else {
                ExtMapBuffer1.set(pos, 0);
            }

            if ((rsi14 <= 70 && sar > high)
                && rsi14 < rsi14_1
                && rsi14 < rsi14_2) {
                ExtMapBuffer2.set(pos, (high + 5 * Current.Point));
            }
            else {
                ExtMapBuffer2.set(pos, 0);
            }
            pos--;
        }
    }
}
